@@ -50,7 +50,7 @@ pub fn wayland_cursor_option() -> Option<&'static WaylandCursor> {
                 Ok(h) => return Some(h),
                 Err(::dlib::DlError::CantOpen(_)) => continue,
                 Err(::dlib::DlError::MissingSymbol(s)) => {
-                    log::error!("Found library {} cannot be used: symbol {} is missing.", ver, s);
+                    log::error!("Found library {ver} cannot be used: symbol {s} is missing.");
                     return None;
                 }
             }
